borderTopContainTopBar property
Whether borderTop contains the height of all Bars at the top. The default value is false.
If isFullScreen is false, borderTopContainTopBar is invalid.
Implementation
final bool borderTopContainTopBar;
Whether borderTop contains the height of all Bars at the top. The default value is false.
If isFullScreen is false, borderTopContainTopBar is invalid.
final bool borderTopContainTopBar;