initPositionXInLeft property

bool initPositionXInLeft
final

Whether the initial position of the component on the x-axis is on the left side of the screen.

true: on the left side of the screen false: on the right side of the screen

Implementation

final bool initPositionXInLeft;