initPositionYMarginBorder property
The distance between the initial position of the component on the y-axis. The default value is zero.
Implementation
final double initPositionYMarginBorder;
The distance between the initial position of the component on the y-axis. The default value is zero.
final double initPositionYMarginBorder;